@@ -6,10 +6,13 @@ import os
 import cv2
 from PIL import Image
 import fire
+import random
+
 
 def process_one(image_type: str, image_name: str, percentage: float,
                 image_root: str, adapted_root: str):
-    target_image = f'{image_root}/{"_".join(image_name.split("_"))}'
+    # TODO: genericise. Currently assumes all file names are the same.
+    target_image = f'{image_root}/{image_type}/{"_".join(image_name.split("_"))}'
     img = cv2.imread(target_image)[:,:,::-1]
     img = cv2.resize(img, (512,512))
 
@@ -30,30 +33,54 @@ def process_one(image_type: str, image_name: str, percentage: float,
 
 def create_viz(
     images = '/efs/public_data/gta5/images',
-    labels = '/efs/public_data/gta5/labels',
+    labels = 'labels',
     adapted = '/efs/public_data/images'):
+
+    labels = '/'.join(images.split('/')[:-1]) + labels
     # set up ui
     label_paths = sorted([ x for x in os.listdir(labels) ])[:1000]
     image_paths = sorted([ x for x in os.listdir(images) ])[:1000]
     adapted_paths = sorted([ x for x in os.listdir(adapted) ])[2:1000]
 
-    im_type = ['images', 'labels']
+    im_type = ['rgb', 'label']
     tar_im_type = st.sidebar.selectbox("Which type of image?", im_type)
 
     file_selection = st.sidebar.selectbox("Which file?", adapted_paths)
 
     percentage = st.sidebar.slider("percentage", 0, 100) / 100
 
+    if st.button('Random Image'):
+        file_selection = random.choice(image_paths)
+    #     i = image_paths.index(file_selection)
+    #     file_selection = image_paths[i+var_i]
+    #     var_i += 1
+        st.code(f"{adapted}/{file_selection}")
+    else:
+        st.write(f'Offset {var_i}')
+
     image_root = '/'.join(images.split('/')[:-1])
     adapted_root = '/'.join(adapted.split('/')[:-1])
 
     kpd_img = process_one(tar_im_type, file_selection, percentage,
                             image_root, adapted_root)
+    kpd_img_1 = process_one(tar_im_type, file_selection, 0,
+                            image_root, adapted_root)
+    kpd_img_2 = process_one(tar_im_type, file_selection, 1,
+                            image_root, adapted_root)
 
-    # st.image(kpd_img, width=900)
-    # import ipdb; ipdb.set_trace()
-    st.image(kpd_img)
+    # st.image(kpd_img, width=256)
+    # st.image(kpd_img_1, width=256)
+    # st.image(kpd_img_2, width=256)
 
+    col1, col2, col3 = st.beta_columns(3)
+    col1.header("Mix")
+    col1.image(kpd_img, use_column_width=True)
+
+    col2.header("Adapted")
+    col2.image(kpd_img_1, use_column_width=True)
+
+    col3.header("Original")
+    col3.image(kpd_img_2, use_column_width=True)
 
 
 if __name__ == "__main__":
