@@ -2,10 +2,16 @@
 import github3
 import pandas as pd
 import sys
+import subprocess as sp
 
 def init():
-    sys.path.append('/Users/jakub/')
-    from .gitconfig import gh_username, gh_password
+    git_config = sp.run(["git","config","-l"], capture_output=True).stdout
+    split_config = git_config.decode().split("\n")
+    git_dict = {s[0]:s[1] for s in [ s.split('=') for s in split_config[:-11] ]}
+
+    gh_username = git_dict['user.email']
+    gh_password = git_dict['user.token']
+
     return gh_username, gh_password
 
 def find_forks(repo_url: str):
@@ -32,6 +38,5 @@ def find_contributors(repo_url: str):
     f = open('/Users/jakub/.gitconfig').read().splitlines()
     c = SshConfig(f)
 
-    import ipdb; ipdb.set_trace()
     g = github3.login(gh_username, gh_password)
     r = g.repository(user, repo)
\ No newline at end of file
